@@ -5,13 +5,14 @@ from pg_tasks_queue.Database import TasksDatabase as database
 
 class TaskManager(object):
 
-    def init(self, database_dict):
+    def init(self, database_dict=None, connection=None, schema=None, auto_disconnect=True):
         func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
         try:
-            if not isinstance(database_dict, dict):
-                print(f'Error in {func_name}: not isinstance(database_dict, dict)...')
-                return False
-            if not database.init(database_dict):
+            kwargs = {'settings': database_dict,
+                      'connection': connection,
+                      'schema': schema,
+                      'auto_disconnect': auto_disconnect}
+            if not database.init(**kwargs):
                 print(f'Error in {func_name}: not database.init(); return...')
                 return False
             if not database.test_tables(create=True):
@@ -42,3 +43,6 @@ class TaskManager(object):
         except Exception as e:
             print(f'Error in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}')
             return None
+
+    def force_disconnect(self):
+        database.force_disconnect()
