@@ -16,7 +16,7 @@ class Worker(object):
     _started = False
     _sleep_sec = 1.
 
-    def init(self, config_dict):
+    def init(self, config_dict, keep_connection=False):
         func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
         try:
             if not isinstance(config_dict, dict):
@@ -26,7 +26,8 @@ class Worker(object):
             if not isinstance(database_dict, dict):
                 print(f'Error in {func_name}: not isinstance(database_dict, dict)...')
                 return False
-            if not database.init(database_dict):
+            kwargs = {'settings': database_dict, 'auto_disconnect': False if keep_connection else True}
+            if not database.init(**kwargs):
                 print(f'Error in {func_name}: not database.init(); return...')
                 return False
             if not database.test_tables(create=False):
